@@ -5,7 +5,9 @@ class Excercise:
         pass
 
     def addTask(self, task):
-        self.tasks[f"{task.task}.{task.subtask}"] = task
+        if task.task not in self.tasks:
+            self.tasks[task.task] = {}
+        self.tasks[task.task][task.subtask] = task
 
     def getTasks(self):
         return self.tasks
